suppy.algorithms
========================

Submodules
----------

suppy.algorithms.level\_set module
----------------------------------

.. automodule:: suppy.algorithms.level_set
   :members:
   :undoc-members:
   :show-inheritance:

suppy.algorithms.projected\_subgradient module
----------------------------------------------

.. automodule:: suppy.algorithms.projected_subgradient
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: suppy.algorithms
   :members:
   :undoc-members:
   :show-inheritance:
